@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021 by Vd.
+# Copyright (C) 2015-2022 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
@@ -20,5 +20,7 @@ class EditChatInviteLink(ChatInviteLinkResultMixin, Request):
 
     chat_id: Union[int, str]
     invite_link: str
+    name: Optional[str] = None
     expire_date: Optional[datetime] = None
     member_limit: Optional[int] = None
+    creates_join_request: Optional[bool] = None
