@@ -1,7 +1,8 @@
-# Copyright (C) 2015-2021 by Vd.
+# Copyright (C) 2015-2022 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
+
 from typing import ClassVar
 
 from . import api
@@ -24,6 +25,12 @@ class RocketgramNetworkError(RocketgramError):
         return "Network error: %s: %s" % (type(self.exception).__name__, self.exception)
 
 
+class RocketgramNetworkTimeoutError(RocketgramNetworkError):
+    """\
+    This exception raised when the request times out.
+    """
+
+
 class RocketgramParseError(RocketgramError):
     """\
     Exception indicates error from json-parser.
@@ -85,6 +92,15 @@ class RocketgramRequest401Error(RocketgramRequestError):
     error_code = 401
 
 
+@RocketgramRequestError.register_exception
+class RocketgramRequest403Error(RocketgramRequestError):
+    """\
+    Exception indicates errors with code 403.
+    """
+
+    error_code = 403
+
+
 @RocketgramRequestError.register_exception
 class RocketgramRequest429Error(RocketgramRequestError):
     """\
