@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021 by Vd.
+# Copyright (C) 2015-2022 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
@@ -21,14 +21,17 @@ def command(*commands: str, case_sensitive: bool = False, separator: str = ' '):
     :return: True or False
     """
 
+    if context.update.type is not UpdateType.message:
+        return False
+
     msg = context.message
     if not msg:
         return False
-    if msg.message_type is not MessageType.text:
+    if msg.type is not MessageType.text:
         return False
 
-    splitted = msg.text.split(sep=separator)
-    text = splitted[0] if case_sensitive else splitted[0].lower()
+    split = msg.text.split(sep=separator)
+    text = split[0] if case_sensitive else split[0].lower()
     bot_name = context.bot.name if case_sensitive else context.bot.name.lower()
 
     for cmd in commands:
@@ -53,10 +56,13 @@ def deeplink(*commands: str, case_sensitive: bool = False):
     :return: True or False
     """
 
+    if context.update.type is not UpdateType.message:
+        return False
+
     msg = context.message
     if not msg:
         return False
-    if msg.message_type is not MessageType.text:
+    if msg.type is not MessageType.text:
         return False
 
     text = msg.text
@@ -101,8 +107,8 @@ def callback(*commands: str, case_sensitive: bool = False, separator=' '):
     if context.update.type is not UpdateType.callback_query:
         return False
 
-    splitted = context.update.callback_query.data.split(sep=separator)
-    text = splitted[0]
+    split = context.update.callback_query.data.split(sep=separator)
+    text = split[0]
     if not case_sensitive:
         text = text.lower()
 
